Enum IntegrityError
pub enum IntegrityError {
UnknownPartInOutputImm {
output_index: usize,
},
UnknownPartInAddrImm {
memory_index: usize,
},
PartHasNoValidMapping {
part_index: usize,
},
MappingDoesNotMatchPartSize {
part_index: usize,
mapping_entries: usize,
part_bits: usize,
},
PartSizeDoesNotMatchBits {
part_index: usize,
},
}Expand description
Error returned by Encoding::integrity_check.
Variants
UnknownPartInOutputImm
The output contains a reference to an immediate value of a non-existant part
UnknownPartInAddrImm
The memory access contains a reference to an immediate value of a non-existant part.
PartHasNoValidMapping
Part has no valid mapping.
MappingDoesNotMatchPartSize
The part mapping has a number of entries that is not equal to the number it should have.
A part mapping should have 2**N entries.
Fields
PartSizeDoesNotMatchBits
The part size does not correspond to the number of Bit::Part(..) bits in self.bits.